within FluidDissipation.Examples.Applications.PressureLoss.BaseClasses.Valve;
package Overall "FluidDissipation: Overall regime of valve"
  extends
    FluidDissipation.Examples.Applications.PressureLoss.BaseClasses.Valve.BaseValvePL;

  redeclare function extends massFlowRate_dp

    //input records for valve function
    input
      FluidDissipation.Examples.Applications.PressureLoss.BaseClasses.Valve.Overall.PressureLossInput_con
      IN_con annotation (Placement(transformation(extent={{-80,20},{-60,40}})));
    input
      FluidDissipation.Examples.Applications.PressureLoss.BaseClasses.Valve.Overall.PressureLossInput_var
      IN_var annotation (Placement(transformation(extent={{-60,20},{-40,40}})));
    input SI.Pressure dp "Pressure loss" annotation (Dialog(tab="Input"));

  algorithm
    M_FLOW :=
      FluidDissipation.PressureLoss.Valve.dp_severalGeometryOverall_MFLOW(
        IN_con,
        IN_var,
        dp);

    annotation (Documentation(info="<html>
<p>
In this package the pressure loss function <a href=\"Modelica://FluidDissipation.PressureLoss.Valve.dp_severalGeometryOverall_MFLOW\"> dp_severalGeometryOverall </a> of a valve out of the <b> FluidDissipation </b> library is  
implemented into an usable form for the replaceable pressure loss calculations of a <a  
href=\"Modelica://FluidDissipation.Examples.Applications.PressureLoss.Valve\"> valve </a> with the <b>Modelica.Fluid </b>  
library as thermo-hydraulic framework. 
</p>
 
<p>
This function executes the calculation of a valve function at the overall flow regime for an incompressible and single-phase  
fluid flow. Here the mass flow rate (M_FLOW) is calculated in dependence of a known  
pressure loss (dp).
</p>
 
<p>
A test case ready for the simulation of a Modelica.Fluid valve function can be found in <a  
href=\"Modelica://FluidDissipation.Examples.TestCases.PressureLoss.Valve\"> Test: Valve functions </a>.
</p>
 
</html>
"));
  end massFlowRate_dp;

  model OverallFlowModel
    "Valve (overall): Application flow model for valve function in Modelica.Fluid"

    //base flow model
    extends
      FluidDissipation.Examples.Applications.PressureLoss.BaseClasses.Valve.BaseValvePL.BaseValveModel;

    //pressure loss calculation
    FluidDissipation.Utilities.Types.ValveGeometry geometry=FluidDissipation.Utilities.Types.ValveGeometry.Ball
      "Choice of geometry for valve" annotation (Dialog(group="Valve"));
    FluidDissipation.Utilities.Types.ValveCoefficient valveCoefficient=
        FluidDissipation.Utilities.Types.ValveCoefficient.AV
      "Choice of valve coefficient" annotation (Dialog(group="Valve"));

    parameter Real opening=1
      "Opening of valve | 0==closed and 1== fully opened"
      annotation (Dialog(group="Valve"));
    parameter Real Av=PI*0.1^2/4 "Av (metric) flow coefficient [Av]=m^2"
      annotation (Dialog(group="Valve"));
    parameter Real Kv=Av/27.7e-6 "Kv (metric) flow coefficient [Kv]=m^3/h"
      annotation (Dialog(group="Valve"));
    parameter Real Cv=Av/24.6e-6 "Cv (US) flow coefficient [Cv]=USG/min"
      annotation (Dialog(group="Valve"));
    parameter SI.Pressure dp_nominal=1e3 "Nominal pressure loss"
      annotation (Dialog(group="Valve"));
    parameter SI.MassFlowRate m_flow_nominal=opening_nominal*Av*(rho_nominal*
        dp_nominal)^0.5 "Nominal mass flow rate"
      annotation (Dialog(group="Valve"));
    parameter Real opening_nominal=0.5 "Nominal opening"
      annotation (Dialog(group="Valve"));
    parameter Real zeta_tot_min=1e-3
      "Minimal pressure loss coefficient at full opening"
      annotation (Dialog(group="Valve"));
    parameter Real zeta_tot_max=1e2
      "Maximum pressure loss coefficient at closed opening"
      annotation (Dialog(group="Valve"));

    FluidDissipation.Examples.Applications.PressureLoss.BaseClasses.Valve.Overall.PressureLossInput_con
      IN_con(
      geometry=geometry,
      valveCoefficient=valveCoefficient,
      Av=Av,
      Kv=Kv,
      Cv=Cv,
      dp_nominal=dp_nominal,
      m_flow_nominal=m_flow_nominal,
      rho_nominal=rho_nominal,
      opening_nominal=opening_nominal,
      dp_small=dp_small,
      zeta_tot_min=zeta_tot_min,
      zeta_tot_max=zeta_tot_max)
      annotation (Placement(transformation(extent={{-80,20},{-60,40}})));

    FluidDissipation.Examples.Applications.PressureLoss.BaseClasses.Valve.Overall.PressureLossInput_var
      IN_var(
      opening=opening,
      rho=rho,
      eta=eta)
      annotation (Placement(transformation(extent={{-60,20},{-40,40}})));

  equation
    m_flow =
      FluidDissipation.Examples.Applications.PressureLoss.BaseClasses.Valve.Overall.massFlowRate_dp(
        IN_con,
        IN_var,
        dp);

    annotation (Diagram(graphics));
  end OverallFlowModel;

  record PressureLossInput_con "Input record for dp_severalGeometryOverall"

    extends
      FluidDissipation.PressureLoss.Valve.dp_severalGeometryOverall_IN_con;

    annotation (Documentation(info="<html>
This record is used as <b> input record </b> for the pressure loss of the <a  
href=\"Modelica://FluidDissipation.PressureLoss.Valve\"> valve function </a> implemented in Modelica.Fluid  
as thermo-hydraulic framework.
</html>"));

  end PressureLossInput_con;

  record PressureLossInput_var "Input record for dp_severalGeometryOverall"

    extends
      FluidDissipation.PressureLoss.Valve.dp_severalGeometryOverall_IN_var;

    annotation (Documentation(info="<html>
This record is used as <b> input record </b> for the pressure loss of the <a  
href=\"Modelica://FluidDissipation.PressureLoss.Valve\"> valve function </a> implemented in Modelica.Fluid  
as thermo-hydraulic framework.
</html>"));

  end PressureLossInput_var;
end Overall;
